summaryrefslogtreecommitdiff
path: root/source4
diff options
context:
space:
mode:
authorGiampaolo Lauria <lauria2@yahoo.com>2011-07-18 11:50:48 -0400
committerAndrew Tridgell <tridge@samba.org>2011-07-21 11:44:30 +1000
commita2e2c130b0472c7d44d6e9d6e98b9f88853bef7b (patch)
tree0689f695d1ac569c71418c735803b929dd8b5f3e /source4
parent903ec440c40bcbf040fc01cab339e42cbf3fdf5c (diff)
downloadsamba-a2e2c130b0472c7d44d6e9d6e98b9f88853bef7b.tar.gz
samba-a2e2c130b0472c7d44d6e9d6e98b9f88853bef7b.tar.bz2
samba-a2e2c130b0472c7d44d6e9d6e98b9f88853bef7b.zip
samba-tool: fixed __doc__ in base classes
Replaced the "net" word with %prog in all instances Signed-off-by: Andrew Tridgell <tridge@samba.org>
Diffstat (limited to 'source4')
-rw-r--r--source4/scripting/python/samba/netcmd/__init__.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/source4/scripting/python/samba/netcmd/__init__.py b/source4/scripting/python/samba/netcmd/__init__.py
index 5e71a1c535..2d345df7b9 100644
--- a/source4/scripting/python/samba/netcmd/__init__.py
+++ b/source4/scripting/python/samba/netcmd/__init__.py
@@ -31,7 +31,7 @@ class Option(optparse.Option):
class Command(object):
- """A net command."""
+ """A %prog command."""
def _get_description(self):
return self.__doc__.splitlines()[0].rstrip("\n")
@@ -148,7 +148,7 @@ class Command(object):
class SuperCommand(Command):
"""A command with subcommands."""
subcommands = {}
@@ -178,7 +178,7 @@ class SuperCommand(Command):
class CommandError(Exception):
- '''an exception class for netcmd errors'''
+ '''an exception class for %prog cmd errors'''
def __init__(self, message, inner_exception=None):
self.message = message
self.inner_exception = inner_exception
@@ -148,7 +148,7 @@ class Command(object):
class SuperCommand(Command):
- """A command with subcommands."""
+ """A %prog command with subcommands."""
subcommands = {}